##
##  mercurial.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         mercurial
Summary:      Disributed Version Control System
URL:          http://www.mercurial-scm.org/
Vendor:       Matt Mackall et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        SCM
License:      GPL
Version:      7.0.1
Release:      20250410

#   list of sources
Source0:      https://www.mercurial-scm.org/release/mercurial-%{version}.tar.gz
Source1:      hgweb.cgi
Source2:      hgweb.cfg

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  python, python::with_bzip2 = yes
PreReq:       python, python::with_bzip2 = yes

%description
    Mercurial is a fast, lightweight Source Control Management (SCM)
    system designed for efficient handling of very large distributed
    projects.

%track
    prog mercurial = {
        version   = %{version}
        url       = https://www.mercurial-scm.org/release/
        regex     = mercurial-(\d+\.\d+(\.\d+)?)\.tar\.gz
    }

%prep
    %setup -q

%build

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/cgi \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/mercurial \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/mercurial \
        $RPM_BUILD_ROOT%{l_prefix}/lib/mercurial \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5
    %{l_shtool} subst \
        -e 's;#!/usr/bin/env python;#!%{l_prefix}/bin/python;g' \
        hg
    %{l_prefix}/bin/python setup.py install \
        --root=$RPM_BUILD_ROOT \
        --prefix=%{l_prefix} \
        --install-lib=%{l_prefix}/lib/mercurial
    mv  $RPM_BUILD_ROOT%{l_prefix}/bin/hg \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/mercurial/hg
    (   echo "#!/bin/sh"
        echo "PYTHONPATH=\"%{l_prefix}/lib/mercurial\""
        echo "export PYTHONPATH"
        echo "%{l_prefix}/bin/python %{l_prefix}/libexec/mercurial/hg \${1+\"\$@\"}"
    ) >$RPM_BUILD_ROOT%{l_prefix}/bin/hg
    chmod 755 $RPM_BUILD_ROOT%{l_prefix}/bin/hg
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE hgweb.cgi} $RPM_BUILD_ROOT%{l_prefix}/cgi/
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE hgweb.cfg} $RPM_BUILD_ROOT%{l_prefix}/etc/mercurial/
    %{l_shtool} install -c -m 644 \
        doc/*.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_shtool} install -c -m 644 \
        doc/*.5 $RPM_BUILD_ROOT%{l_prefix}/man/man5/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/mercurial/*'

%files -f files

%clean

